@@ -4,9 +4,9 @@
     'name': 'Sale',
     'name_de_DE': 'Verkauf',
     'name_es_CO': 'Ventas',
-    'name_es_ES': 'Ventas',
+    'name_es_ES': 'Venta',
     'name_fr_FR': 'Vente',
-    'version': '1.2.7',
+    'version': '1.4.4',
     'author': 'B2CK',
     'email': 'info@b2ck.com',
     'website': 'http://www.tryton.org/',
@@ -16,12 +16,12 @@ Add to product sale informations.
 Define the sale price as the list price.
 
 With the possibilities:
-    - to follow invoice and packing states from the sale order.
+    - to follow invoice and shipment states from the sale order.
     - to define invoice method:
         - Manual
         - On Order Confirmed
-        - On packing Sent
-    - to define packing method:
+        - On shipment Sent
+    - to define shipment method:
         - Manual
         - On Order Confirmed
         - On Invoice Paid
@@ -56,34 +56,34 @@ Ermöglicht:
         - Al Confirmar la Orden
         - Contra el Pago de la Factura
 ''',
-    'description_es_ES': ''' - Define la orden de Ventas.
- - Se añade al producto la información de ventas.
- - Definición del precio de venta y el precio de lista.
+    'description_es_ES': '''Define orden de venta.
+ - Añade a los productos información de ventas.
+ - Define el precio de venta como el precio de lista.
 
- - Con las posibilidades de:
-    - seguir los estados de facturación y empaque desde la orden de venta.
+ - Con la posibilidad de:
+    - seguir los estados de facturación y envio desde la orden de venta.
     - definir el método de facturación:
         - Manual
-        - Al Confirmar la Orden
-        - Al Envío del Paquete
-    - definir el método de empaque:
+        - A la confirmación de la orden
+        - Al enviarlo
+    - definir el método de envio:
         - Manual
-        - Al Confirmar la Orden
-        - Contra el Pago de la Factura
+        - Al confirmar la orden
+        - Al pagar la factura
 ''',
     'description_fr_FR': '''Défini l'ordre de vente.
-Ajoute au produit les information de vente.
+Ajoute au produit les informations de vente.
 
 Avec la possibilité:
-    ' de suivre l'état de la facture et du colisage depuis l'ordre de vente
-    ' de choisir entre plusieurs méthodes de facturation:
-        ' Manuelle
-        ' Sur confirmation de la commande
-        ' À la livraison
-    ' de choisir entre plusieurs méthodes de colisage:
-        ' Manuel
-        ' Sur confirmation de la commande
-        ' Au paiement de la facture
+    - de suivre l'état de la facture et du colisage depuis l'ordre de vente
+    - de choisir entre plusieurs méthodes de facturation:
+        - Manuelle
+        - Sur confirmation de la commande
+        - À la livraison
+    - de choisir entre plusieurs méthodes de colisage:
+        - Manuelle
+        - Sur confirmation de la commande
+        - Au paiement de la facture
 ''',
     'depends': [
         'company',
