@@ -2,10 +2,11 @@
 #of this repository contains the full copyright notices and license terms.
 "Sale"
 from trytond.model import ModelWorkflow, ModelView, ModelSQL, fields
-from trytond.report import CompanyReport
+from trytond.modules.company import CompanyReport
 from trytond.wizard import Wizard
 from trytond.backend import TableHandler
 from decimal import Decimal
+import copy
 
 
 class Sale(ModelWorkflow, ModelSQL, ModelView):
@@ -17,8 +18,8 @@ class Sale(ModelWorkflow, ModelSQL, ModelView):
     company = fields.Many2One('company.company', 'Company', required=True,
             states={
                 'readonly': "state != 'draft' or bool(lines)",
-            }, domain="[('id', 'company' in context and '=' or '!=', " \
-                    "context.get('company', 0))]")
+            }, domain=["('id', 'company' in context and '=' or '!=', " \
+                    "context.get('company', 0))"])
     reference = fields.Char('Reference', readonly=True, select=1)
     description = fields.Char('Description', states={
         'readonly': "state != 'draft'",
@@ -44,11 +45,11 @@ class Sale(ModelWorkflow, ModelSQL, ModelView):
     party_lang = fields.Function('get_function_fields', type='char',
             string='Party Language', on_change_with=['party'])
     invoice_address = fields.Many2One('party.address', 'Invoice Address',
-            domain="[('party', '=', party)]", states={
+            domain=["('party', '=', party)"], states={
                 'readonly': "state != 'draft'",
             })
-    packing_address = fields.Many2One('party.address', 'Shipment Address',
-            domain="[('party', '=', party)]", states={
+    shipment_address = fields.Many2One('party.address', 'Shipment Address',
+            domain=["('party', '=', party)"], states={
                 'readonly': "state != 'draft'",
             })
     warehouse = fields.Many2One('stock.location', 'Warehouse',
@@ -74,7 +75,7 @@ class Sale(ModelWorkflow, ModelSQL, ModelView):
     invoice_method = fields.Selection([
         ('manual', 'Manual'),
         ('order', 'On Order Confirmed'),
-        ('packing', 'On Shipment Sent'),
+        ('shipment', 'On Shipment Sent'),
     ], 'Invoice Method', required=True, states={
         'readonly': "state != 'draft'",
         })
@@ -94,26 +95,26 @@ class Sale(ModelWorkflow, ModelSQL, ModelView):
             string='Invoices Paid')
     invoice_exception = fields.Function('get_function_fields', type='boolean',
             string='Invoices Exception')
-    packing_method = fields.Selection([
+    shipment_method = fields.Selection([
         ('manual', 'Manual'),
         ('order', 'On Order Confirmed'),
         ('invoice', 'On Invoice Paid'),
     ], 'Shipment Method', required=True, states={
         'readonly': "state != 'draft'",
         })
-    packing_state = fields.Selection([
+    shipment_state = fields.Selection([
         ('none', 'None'),
         ('waiting', 'Waiting'),
         ('sent', 'Sent'),
         ('exception', 'Exception'),
     ], 'Shipment State', readonly=True, required=True)
-    packings = fields.Function('get_function_fields', type='many2many',
-            relation='stock.packing.out', string='Shipments')
+    shipments = fields.Function('get_function_fields', type='many2many',
+            relation='stock.shipment.out', string='Shipments')
     moves = fields.Function('get_function_fields', type='many2many',
             relation='stock.move', string='Moves')
-    packing_done = fields.Function('get_function_fields', type='boolean',
+    shipment_done = fields.Function('get_function_fields', type='boolean',
             string='Shipment Done')
-    packing_exception = fields.Function('get_function_fields', type='boolean',
+    shipment_exception = fields.Function('get_function_fields', type='boolean',
             string='Shipments Exception')
 
     def __init__(self):
@@ -131,6 +132,30 @@ class Sale(ModelWorkflow, ModelSQL, ModelView):
                     'an "Account Receivable" on the party "%s"!',
         })
 
+    def init(self, cursor, module_name):
+        # Migration from 1.2: packing renamed into shipment
+        cursor.execute("UPDATE ir_model_data "\
+                "SET fs_id = REPLACE(fs_id, 'packing', 'shipment') "\
+                "WHERE fs_id like '%%packing%%' AND module = %s",
+                (module_name,))
+        cursor.execute("UPDATE ir_model_field "\
+                "SET relation = REPLACE(relation, 'packing', 'shipment'), "\
+                    "name = REPLACE(name, 'packing', 'shipment') "
+                "WHERE (relation like '%%packing%%' "\
+                    "OR name like '%%packing%%') AND module = %s",
+                (module_name,))
+        table = TableHandler(cursor, self, module_name)
+        table.column_rename('packing_state', 'shipment_state')
+        table.column_rename('packing_method', 'shipment_method')
+        table.column_rename('packing_address', 'shipment_address')
+
+        super(Sale, self).init(cursor, module_name)
+
+        # Migration from 1.2
+        cursor.execute("UPDATE " + self._table + " "\
+                "SET invoice_method = 'shipment' "\
+                "WHERE invoice_method = 'packing'")
+
     def default_payment_term(self, cursor, user, context=None):
         payment_term_obj = self.pool.get('account.invoice.payment_term')
         payment_term_ids = payment_term_obj.search(cursor, user,
@@ -191,10 +216,10 @@ class Sale(ModelWorkflow, ModelSQL, ModelView):
     def default_invoice_state(self, cursor, user, context=None):
         return 'none'
 
-    def default_packing_method(self, cursor, user, context=None):
+    def default_shipment_method(self, cursor, user, context=None):
         return 'order'
 
-    def default_packing_state(self, cursor, user, context=None):
+    def default_shipment_state(self, cursor, user, context=None):
         return 'none'
 
     def on_change_party(self, cursor, user, ids, vals, context=None):
@@ -203,7 +228,7 @@ class Sale(ModelWorkflow, ModelSQL, ModelView):
         payment_term_obj = self.pool.get('account.invoice.payment_term')
         res = {
             'invoice_address': False,
-            'packing_address': False,
+            'shipment_address': False,
             'payment_term': False,
         }
         if vals.get('party'):
@@ -211,7 +236,7 @@ class Sale(ModelWorkflow, ModelSQL, ModelView):
                     context=context)
             res['invoice_address'] = party_obj.address_get(cursor, user,
                     party.id, type='invoice', context=context)
-            res['packing_address'] = party_obj.address_get(cursor, user,
+            res['shipment_address'] = party_obj.address_get(cursor, user,
                     party.id, type='delivery', context=context)
             if party.payment_term:
                 res['payment_term'] = party.payment_term.id
@@ -219,9 +244,9 @@ class Sale(ModelWorkflow, ModelSQL, ModelView):
         if res['invoice_address']:
             res['invoice_address.rec_name'] = address_obj.browse(cursor, user,
                     res['invoice_address'], context=context).rec_name
-        if res['packing_address']:
-            res['packing_address.rec_name'] = address_obj.browse(cursor, user,
-                    res['packing_address'], context=context).rec_name
+        if res['shipment_address']:
+            res['shipment_address.rec_name'] = address_obj.browse(cursor, user,
+                    res['shipment_address'], context=context).rec_name
         if not res['payment_term']:
             res['payment_term'] = self.default_payment_term(cursor, user,
                     context=context)
@@ -388,16 +413,16 @@ class Sale(ModelWorkflow, ModelSQL, ModelView):
         if 'invoice_exception' in names:
             res['invoice_exception'] = self.get_invoice_exception(cursor, user,
                     sales, context=context)
-        if 'packings' in names:
-            res['packings'] = self.get_packings(cursor, user, sales,
+        if 'shipments' in names:
+            res['shipments'] = self.get_shipments(cursor, user, sales,
                     context=context)
         if 'moves' in names:
             res['moves'] = self.get_moves(cursor, user, sales, context=context)
-        if 'packing_done' in names:
-            res['packing_done'] = self.get_packing_done(cursor, user, sales,
+        if 'shipment_done' in names:
+            res['shipment_done'] = self.get_shipment_done(cursor, user, sales,
                     context=context)
-        if 'packing_exception' in names:
-            res['packing_exception'] = self.get_packing_exception(cursor, user,
+        if 'shipment_exception' in names:
+            res['shipment_exception'] = self.get_shipment_exception(cursor, user,
                     sales, context=context)
         return res
 
@@ -538,25 +563,25 @@ class Sale(ModelWorkflow, ModelSQL, ModelView):
             res[sale.id] = val
         return res
 
-    def get_packings(self, cursor, user, sales, context=None):
+    def get_shipments(self, cursor, user, sales, context=None):
         '''
-        Return packing_out ids for each sales
+        Return shipment_out ids for each sales
 
         :param cursor: the database cursor
         :param user: the user id
         :param sales: a BrowseRecordList of sales
         :param context: the context
         :return: a dictionary with sale id as key and
-            a list of packing_out id as value
+            a list of shipment_out id as value
         '''
         res = {}
         for sale in sales:
             res[sale.id] = []
             for line in sale.lines:
                 for move in line.moves:
-                    if move.packing_out:
-                        if move.packing_out.id not in res[sale.id]:
-                            res[sale.id].append(move.packing_out.id)
+                    if move.shipment_out:
+                        if move.shipment_out.id not in res[sale.id]:
+                            res[sale.id].append(move.shipment_out.id)
         return res
 
     def get_moves(self, cursor, user, sales, context=None):
@@ -577,9 +602,9 @@ class Sale(ModelWorkflow, ModelSQL, ModelView):
                 res[sale.id].extend([x.id for x in line.moves])
         return res
 
-    def get_packing_done(self, cursor, user, sales, context=None):
+    def get_shipment_done(self, cursor, user, sales, context=None):
         '''
-        Return if all the packings have been done for each sales
+        Return if all the shipments have been done for each sales
 
         :param cursor: the database cursor
         :param user: the user id
@@ -598,9 +623,9 @@ class Sale(ModelWorkflow, ModelSQL, ModelView):
             res[sale.id] = val
         return res
 
-    def get_packing_exception(self, cursor, user, sales, context=None):
+    def get_shipment_exception(self, cursor, user, sales, context=None):
         '''
-        Return if there is a packing exception for each sales
+        Return if there is a shipment exception for each sales
 
         :param cursor: the database cursor
         :param user: the user id
@@ -624,11 +649,11 @@ class Sale(ModelWorkflow, ModelSQL, ModelView):
         Check the methods.
         '''
         for sale in self.browse(cursor, user, ids):
-            if sale.invoice_method == 'packing' \
-                    and sale.packing_method in ('invoice', 'manual'):
+            if sale.invoice_method == 'shipment' \
+                    and sale.shipment_method in ('invoice', 'manual'):
                 return False
-            if sale.packing_method == 'invoice' \
-                    and sale.invoice_method in ('packing', 'manual'):
+            if sale.shipment_method == 'invoice' \
+                    and sale.invoice_method in ('shipment', 'manual'):
                 return False
         return True
 
@@ -661,13 +686,13 @@ class Sale(ModelWorkflow, ModelSQL, ModelView):
         default['invoice_state'] = 'none'
         default['invoices'] = False
         default['invoices_ignored'] = False
-        default['packing_state'] = 'none'
+        default['shipment_state'] = 'none'
         return super(Sale, self).copy(cursor, user, ids, default=default,
                 context=context)
 
     def check_for_quotation(self, cursor, user, sale_id, context=None):
         sale = self.browse(cursor, user, sale_id, context=context)
-        if not sale.invoice_address or not sale.packing_address:
+        if not sale.invoice_address or not sale.shipment_address:
             self.raise_user_error(cursor, 'addresses_required', context=context)
         return True
 
@@ -705,7 +730,7 @@ class Sale(ModelWorkflow, ModelSQL, ModelView):
         :param sale: the BrowseRecord of the sale
         :param context: the context
 
-        :return: a dictionary with invoiced sale line id as key
+        :return: a dictionary with invoice line as key
             and a list of invoice lines values as value
         '''
         line_obj = self.pool.get('sale.line')
@@ -717,6 +742,39 @@ class Sale(ModelWorkflow, ModelSQL, ModelView):
                 res[line.id] = val
         return res
 
+    def _get_invoice_sale(self, cursor, user, sale, context=None):
+        '''
+        Return invoice values for sale
+
+        :param cursor: the database cursor
+        :param user: the user id
+        :param sale: the BrowseRecord of the sale
+        :param context: the context
+
+        :return: a dictionary with invoice fields as key and
+            invoice values as value
+        '''
+        journal_obj = self.pool.get('account.journal')
+
+        journal_id = journal_obj.search(cursor, user, [
+            ('type', '=', 'revenue'),
+            ], limit=1, context=context)
+        if journal_id:
+            journal_id = journal_id[0]
+
+        res = {
+            'company': sale.company.id,
+            'type': 'out_invoice',
+            'reference': sale.reference,
+            'journal': journal_id,
+            'party': sale.party.id,
+            'invoice_address': sale.invoice_address.id,
+            'currency': sale.currency.id,
+            'account': sale.party.account_receivable.id,
+            'payment_term': sale.payment_term.id,
+            }
+        return res
+
     def create_invoice(self, cursor, user, sale_id, context=None):
         '''
         Create an invoice for the sale
@@ -729,7 +787,6 @@ class Sale(ModelWorkflow, ModelSQL, ModelView):
         :return: the created invoice id or None
         '''
         invoice_obj = self.pool.get('account.invoice')
-        journal_obj = self.pool.get('account.journal')
         invoice_line_obj = self.pool.get('account.invoice.line')
         sale_line_obj = self.pool.get('sale.line')
 
@@ -747,34 +804,18 @@ class Sale(ModelWorkflow, ModelSQL, ModelView):
         if not invoice_lines:
             return
 
-        journal_id = journal_obj.search(cursor, user, [
-            ('type', '=', 'revenue'),
-            ], limit=1, context=context)
-        if journal_id:
-            journal_id = journal_id[0]
 
         ctx = context.copy()
         ctx['user'] = user
-        invoice_id = invoice_obj.create(cursor, 0, {
-            'company': sale.company.id,
-            'type': 'out_invoice',
-            'reference': sale.reference,
-            'journal': journal_id,
-            'party': sale.party.id,
-            'invoice_address': sale.invoice_address.id,
-            'currency': sale.currency.id,
-            'account': sale.party.account_receivable.id,
-            'payment_term': sale.payment_term.id,
-        }, context=ctx)
+        vals = self._get_invoice_sale(cursor, user, sale, context=context)
+        invoice_id = invoice_obj.create(cursor, 0, vals, context=ctx)
 
-        for line in sale.lines:
-            if line.id not in invoice_lines:
-                continue
-            for vals in invoice_lines[line.id]:
+        for line_id in invoice_lines:
+            for vals in invoice_lines[line_id]:
                 vals['invoice'] = invoice_id
                 invoice_line_id = invoice_line_obj.create(cursor, 0, vals,
                         context=ctx)
-                sale_line_obj.write(cursor, user, line.id, {
+                sale_line_obj.write(cursor, user, line_id, {
                     'invoice_lines': [('add', invoice_line_id)],
                     }, context=context)
 
@@ -804,18 +845,18 @@ class Sale(ModelWorkflow, ModelSQL, ModelView):
                 res[line.id] = val
         return res
 
-    def create_packing(self, cursor, user, sale_id, context=None):
+    def create_shipment(self, cursor, user, sale_id, context=None):
         '''
-        Create a packing for the sale
+        Create a shipment for the sale
 
         :param cursor: the database cursor
         :param user: the user id
         :param sale_id: the sale id
         :param context: the context
 
-        :return: the created packing id or None
+        :return: the created shipment id or None
         '''
-        packing_obj = self.pool.get('stock.packing.out')
+        shipment_obj = self.pool.get('stock.shipment.out')
         move_obj = self.pool.get('stock.move')
         sale_line_obj = self.pool.get('sale.line')
 
@@ -830,24 +871,24 @@ class Sale(ModelWorkflow, ModelSQL, ModelView):
 
         ctx = context.copy()
         ctx['user'] = user
-        packing_id = packing_obj.create(cursor, 0, {
+        shipment_id = shipment_obj.create(cursor, 0, {
             'planned_date': sale.sale_date,
             'customer': sale.party.id,
-            'delivery_address': sale.packing_address.id,
+            'delivery_address': sale.shipment_address.id,
             'reference': sale.reference,
             'warehouse': sale.warehouse.id,
         }, context=ctx)
 
         for line_id in moves:
             vals = moves[line_id]
-            vals['packing_out'] = packing_id
+            vals['shipment_out'] = shipment_id
             move_id = move_obj.create(cursor, 0, vals, context=ctx)
             sale_line_obj.write(cursor, 0, line_id, {
                 'moves': [('add', move_id)],
                 }, context=ctx)
-        packing_obj.workflow_trigger_validate(cursor, 0, packing_id,
+        shipment_obj.workflow_trigger_validate(cursor, 0, shipment_id,
                 'waiting', context=ctx)
-        return packing_id
+        return shipment_id
 
 Sale()
 
@@ -918,8 +959,8 @@ class SaleLine(ModelSQL, ModelView):
                 'required': "product",
                 'invisible': "type != 'line'",
                 'readonly': "not globals().get('_parent_sale')",
-            }, domain="[('category', '=', " \
-                    "(product, 'product.default_uom.category'))]",
+            }, domain=["('category', '=', " \
+                    "(product, 'product.default_uom.category'))"],
             context="{'category': (product, 'product.default_uom.category')}",
             on_change=['product', 'quantity', 'unit', '_parent_sale.currency',
                 '_parent_sale.party'])
@@ -1072,6 +1113,21 @@ class SaleLine(ModelSQL, ModelView):
         res = {}
         return res
 
+    def _get_context_sale_price(self, cursor, user, product, vals,
+            context=None):
+        if context is None:
+            context = {}
+        ctx2 = context.copy()
+        if vals.get('_parent_sale.currency'):
+            ctx2['currency'] = vals['_parent_sale.currency']
+        if vals.get('_parent_sale.party'):
+            ctx2['customer'] = vals['_parent_sale.party']
+        if vals.get('unit'):
+            ctx2['uom'] = vals['unit']
+        else:
+            ctx2['uom'] = product.sale_uom.id
+        return ctx2
+
     def on_change_product(self, cursor, user, ids, vals, context=None):
         party_obj = self.pool.get('party.party')
         product_obj = self.pool.get('product.product')
@@ -1095,15 +1151,8 @@ class SaleLine(ModelSQL, ModelView):
         product = product_obj.browse(cursor, user, vals['product'],
                 context=context)
 
-        ctx2 = context.copy()
-        if vals.get('_parent_sale.currency'):
-            ctx2['currency'] = vals['_parent_sale.currency']
-        if vals.get('_parent_sale.party'):
-            ctx2['customer'] = vals['_parent_sale.party']
-        if vals.get('unit'):
-            ctx2['uom'] = vals['unit']
-        else:
-            ctx2['uom'] = product.sale_uom.id
+        ctx2 = self._get_context_sale_price(cursor, user, product, vals,
+                context=context)
         res['unit_price'] = product_obj.get_sale_price(cursor, user,
                 [product.id], vals.get('quantity', 0), context=ctx2)[product.id]
         res['taxes'] = []
@@ -1155,13 +1204,8 @@ class SaleLine(ModelSQL, ModelView):
         product = product_obj.browse(cursor, user, vals['product'],
                 context=context)
 
-        ctx2 = context.copy()
-        if vals.get('_parent_sale.currency'):
-            ctx2['currency'] = vals['_parent_sale.currency']
-        if vals.get('_parent_sale.party'):
-            ctx2['customer'] = vals['_parent_sale.party']
-        if vals.get('unit'):
-            ctx2['uom'] = vals['unit']
+        ctx2 = self._get_context_sale_price(cursor, user, product, vals,
+                context=context)
         res['unit_price'] = product_obj.get_sale_price(cursor, user,
                 [vals['product']], vals.get('quantity', 0),
                 context=ctx2)[vals['product']]
@@ -1230,9 +1274,7 @@ class SaleLine(ModelSQL, ModelView):
         if line.type != 'line':
             return [res]
 
-        if (line.sale.invoice_method == 'order'
-                or not line.product
-                or line.product.type == 'service'):
+        if line.sale.invoice_method == 'order':
             quantity = line.quantity
         else:
             quantity = 0.0
@@ -1244,7 +1286,7 @@ class SaleLine(ModelSQL, ModelView):
         ignored_ids = set(
             l.id for i in line.sale.invoices_ignored for l in i.lines)
         for invoice_line in line.invoice_lines:
-            if ((invoice_line.invoice and
+            if ((invoice_lines.invoice and
                     invoice_line.invoice.state != 'cancel') or
                 invoice_line.id in ignored_ids):
                 quantity -= uom_obj.compute_qty(
@@ -1399,10 +1441,34 @@ class Template(ModelSQL, ModelView):
         'readonly': "active == False",
         'invisible': "not salable",
         'required': "salable",
-        }, domain="[('category', '=', " \
-                "(default_uom, 'uom.category'))]",
+        }, domain=["('category', '=', (default_uom, 'uom.category'))"],
         context="{'category': (default_uom, 'uom.category')}",
-        on_change_with=['default_uom', 'sale_uom'])
+        on_change_with=['default_uom', 'sale_uom', 'salable'])
+
+    def __init__(self):
+        super(Template, self).__init__()
+        if 'not bool(account_category) and bool(salable)' not in \
+                self.account_revenue.states.get('required', ''):
+            self.account_revenue = copy.copy(self.account_revenue)
+            self.account_revenue.states = copy.copy(self.account_revenue.states)
+            if not self.account_revenue.states.get('required'):
+                self.account_revenue.states['required'] = \
+                        "not bool(account_category) and bool(salable)"
+            else:
+                self.account_revenue.states['required'] = '(' + \
+                        self.account_revenue.states['required'] + ') ' \
+                        'or (not bool(account_category) and bool(salable))'
+        if 'account_category' not in self.account_revenue.depends:
+            self.account_revenue = copy.copy(self.account_revenue)
+            self.account_revenue.depends = \
+                    copy.copy(self.account_revenue.depends)
+            self.account_revenue.depends.append('account_category')
+        if 'salable' not in self.account_revenue.depends:
+            self.account_revenue = copy.copy(self.account_revenue)
+            self.account_revenue.depends = \
+                    copy.copy(self.account_revenue.depends)
+            self.account_revenue.depends.append('salable')
+        self._reset_columns()
 
     def default_salable(self, cursor, user, context=None):
         if context is None:
@@ -1490,11 +1556,11 @@ class Product(ModelSQL, ModelView):
 Product()
 
 
-class PackingOut(ModelSQL, ModelView):
-    _name = 'stock.packing.out'
+class ShipmentOut(ModelSQL, ModelView):
+    _name = 'stock.shipment.out'
 
     def __init__(self):
-        super(PackingOut, self).__init__()
+        super(ShipmentOut, self).__init__()
         self._error_messages.update({
                 'reset_move': 'You cannot reset to draft a move generated '\
                     'by a sale.',
@@ -1504,7 +1570,7 @@ class PackingOut(ModelSQL, ModelView):
         sale_obj = self.pool.get('sale.sale')
         sale_line_obj = self.pool.get('sale.line')
 
-        res = super(PackingOut, self).write(cursor, user, ids, vals,
+        res = super(ShipmentOut, self).write(cursor, user, ids, vals,
                 context=context)
 
         if 'state' in vals and vals['state'] in ('done', 'cancel'):
@@ -1512,8 +1578,8 @@ class PackingOut(ModelSQL, ModelView):
             move_ids = []
             if isinstance(ids, (int, long)):
                 ids = [ids]
-            for packing in self.browse(cursor, user, ids, context=context):
-                move_ids.extend([x.id for x in packing.outgoing_moves])
+            for shipment in self.browse(cursor, user, ids, context=context):
+                move_ids.extend([x.id for x in shipment.outgoing_moves])
 
             sale_line_ids = sale_line_obj.search(cursor, user, [
                 ('moves', 'in', move_ids),
@@ -1525,19 +1591,19 @@ class PackingOut(ModelSQL, ModelView):
                         sale_ids.append(sale_line.sale.id)
 
             sale_obj.workflow_trigger_validate(cursor, user, sale_ids,
-                    'packing_update', context=context)
+                    'shipment_update', context=context)
         return res
 
     def button_draft(self, cursor, user, ids, context=None):
-        for packing in self.browse(cursor, user, ids, context=context):
-            for move in packing.outgoing_moves:
+        for shipment in self.browse(cursor, user, ids, context=context):
+            for move in shipment.outgoing_moves:
                 if move.state == 'cancel' and move.sale_line:
                     self.raise_user_error(cursor, 'reset_move')
 
-        return super(PackingOut, self).button_draft(
+        return super(ShipmentOut, self).button_draft(
             cursor, user, ids, context=context)
 
-PackingOut()
+ShipmentOut()
 
 
 class Move(ModelSQL, ModelView):
@@ -1607,7 +1673,7 @@ class Move(ModelSQL, ModelView):
                     sale_ids.add(sale_line.sale.id)
             if sale_ids:
                 sale_obj.workflow_trigger_validate(cursor, user, list(sale_ids),
-                        'packing_update', context=context)
+                        'shipment_update', context=context)
         return res
 
     def delete(self, cursor, user, ids, context=None):
@@ -1630,7 +1696,7 @@ class Move(ModelSQL, ModelView):
                 sale_ids.add(sale_line.sale.id)
             if sale_ids:
                 sale_obj.workflow_trigger_validate(cursor, user, list(sale_ids),
-                        'packing_update', context=context)
+                        'shipment_update', context=context)
         return res
 
 Move()
@@ -1693,9 +1759,9 @@ class Invoice(ModelSQL, ModelView):
         if isinstance(ids, (int, long)):
             ids = [ids]
         cursor.execute('SELECT id FROM sale_invoices_rel ' \
-                'WHERE invoice IN (' + ','.join(['%s' for x in ids]) + ')',
+                'WHERE invoice IN (' + ','.join(('%s',) * len(ids)) + ')',
                 ids)
-        if cursor.rowcount:
+        if cursor.fetchone():
             self.raise_user_error(cursor, 'delete_sale_invoice',
                     context=context)
         return super(Invoice, self).delete(cursor, user, ids,
@@ -1751,17 +1817,25 @@ class OpenCustomer(Wizard):
 OpenCustomer()
 
 
-class HandlePackingExceptionAsk(ModelView):
+class HandleShipmentExceptionAsk(ModelView):
     'Shipment Exception Ask'
-    _name = 'sale.handle.packing.exception.ask'
+    _name = 'sale.handle.shipment.exception.ask'
     _description = __doc__
 
     recreate_moves = fields.Many2Many(
         'stock.move', None, None, 'Recreate Moves',
-        domain="[('id', 'in', domain_moves)]", depends=['domain_moves'])
+        domain=["('id', 'in', domain_moves)"], depends=['domain_moves'])
     domain_moves = fields.Many2Many(
         'stock.move', None, None, 'Domain Moves')
 
+    def init(self, cursor, module_name):
+        # Migration from 1.2: packing renamed into shipment
+        cursor.execute("UPDATE ir_model "\
+                "SET model = REPLACE(model, 'packing', 'shipment') "\
+                "WHERE model like '%%packing%%' AND module = %s",
+                (module_name,))
+        super(HandleShipmentExceptionAsk, self).init(cursor, module_name)
+
     def default_recreate_moves(self, cursor, user, context=None):
         return self.default_domain_moves(cursor, user, context=context)
 
@@ -1786,17 +1860,17 @@ class HandlePackingExceptionAsk(ModelView):
 
         return domain_moves
 
-HandlePackingExceptionAsk()
+HandleShipmentExceptionAsk()
 
-class HandlePackingException(Wizard):
+class HandleShipmentException(Wizard):
     'Handle Shipment Exception'
-    _name = 'sale.handle.packing.exception'
+    _name = 'sale.handle.shipment.exception'
     states = {
         'init': {
             'actions': [],
             'result': {
                 'type': 'form',
-                'object': 'sale.handle.packing.exception.ask',
+                'object': 'sale.handle.shipment.exception.ask',
                 'state': [
                     ('end', 'Cancel', 'tryton-cancel'),
                     ('ok', 'Ok', 'tryton-ok', True),
@@ -1816,7 +1890,7 @@ class HandlePackingException(Wizard):
         sale_obj = self.pool.get('sale.sale')
         sale_line_obj = self.pool.get('sale.line')
         move_obj = self.pool.get('stock.move')
-        packing_obj = self.pool.get('stock.packing.out')
+        shipment_obj = self.pool.get('stock.shipment.out')
         to_recreate = data['form']['recreate_moves'][0][1]
         domain_moves = data['form']['domain_moves'][0][1]
 
@@ -1842,9 +1916,9 @@ class HandlePackingException(Wizard):
                 context=context)
 
         sale_obj.workflow_trigger_validate(cursor, user, data['id'],
-                'packing_ok', context=context)
+                'shipment_ok', context=context)
 
-HandlePackingException()
+HandleShipmentException()
 
 
 class HandleInvoiceExceptionAsk(ModelView):
@@ -1854,7 +1928,7 @@ class HandleInvoiceExceptionAsk(ModelView):
 
     recreate_invoices = fields.Many2Many(
         'account.invoice', None, None, 'Recreate Invoices',
-        domain="[('id', 'in', domain_invoices)]", depends=['domain_invoices'],
+        domain=["('id', 'in', domain_invoices)"], depends=['domain_invoices'],
         help='The selected invoices will be recreated. '\
             'The other ones will be ignored.')
     domain_invoices = fields.Many2Many(
